@@ -16,8 +16,8 @@
 # limitations under the License.
 #
 
-require "time"
-require File.expand_path(File.join(File.dirname(__FILE__), "..", "..", "spec_helper"))
+require "time" unless defined?(Time.zone_offset)
+require "spec_helper"
 
 RSpec.describe Mixlib::Log::Formatter do
   before(:each) do
